<?php
/**
 * Created by PhpStorm.
 * User: zilongs
 * Date: 20-9-23
 * Time: 上午11:26
 */

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Models\User;
use EasyWeChat\Factory;

class CommonController extends Controller
{
    public function wxLogin()
    {
        $req = request()->post();
        $this->validate(request(), [
            'wechat_code' => 'required',
            'nickname|昵称' => 'max:50',
            'avatar|头像' => 'url',
            'latitude|纬度' => 'numeric',
            'longitude|纬度' => 'numeric',
        ]);

        $app = Factory::miniProgram(config('config.wechat_small_program'));
        $data = $app->auth->session($req['wechat_code']);
        if (empty($data['openid'])){
            return out(null, 10001, '微信登录code错误');
        }

        $session_key = !empty($data['session_key']) ? $data['session_key'] : '';
        $user = User::select(['id', 'status', 'phone', 'nickname', 'avatar'])->where('openid', $data['openid'])->first();
        if (empty($user)){
            $user = User::create([
                'openid' => $data['openid'],
                'nickname' => $req['nickname'] ?? '',
                'avatar' => $req['avatar'] ?? '',
                'latitude' => $req['latitude'] ?? 0,
                'longitude' => $req['longitude'] ?? 0,
                'session_key' => $session_key
            ]);
        }
        else {
            if ($user['status'] == 0) {
                return out(null, 10002, '该账号已被冻结');
            }

            User::where('id', $user['id'])->update([
                'nickname' => $req['nickname'] ?? '',
                'avatar' => $req['avatar'] ?? '',
                'latitude' => $req['latitude'] ?? 0,
                'longitude' => $req['longitude'] ?? 0,
                'session_key' => $session_key
            ]);
        }

        $token = aes_encrypt(['id' => $user['id'], 'time' => time()]);

        return out(['token' => $token]);
    }

    public function uploadFile()
    {
        $file = request()->file('file');
        if (empty($file)) {
            return out(null, 10001, '文件不能为空');
        }

        $path = $file->store('uploads/'.date('Ymd'));
        $url = request()->getScheme().'://'.request()->getHost().'/'.$path;

        return out(['url' => $url]);
    }

    public function doc()
    {
        $database = env('DB_DATABASE');
        $prefix = env('DB_PREFIX');
        $map1 = [
            'users' => 'users(用户表)',
            'organizations' => 'organizations(机构表)',
            'orders' => 'orders(订单表)',
            'order_patients' => 'order_patients(订单患者表)',
            'order_vaccines' => 'order_vaccines(订单疫苗表)',
            'order_nurses' => 'order_nurses(订单儿保表)',
            'order_packs' => 'order_packs(订单服务包表)',
            'schedules' => 'schedules(排班表)',
            'schedule_periods' => 'schedule_periods(排班时间段表)',
            'qualifications' => 'qualifications(医生资质表)',
            'coupons' => 'coupons(优惠券表)',
            'coupon_types' => 'coupon_types(优惠券类型表)',
        ];

        $data1 = array();
        foreach ($map1 as $k => $v){
            $sql = "select COLUMN_NAME name, DATA_TYPE type, COLUMN_COMMENT comment from INFORMATION_SCHEMA.COLUMNS where table_schema = '".$database."' AND table_name = '".$prefix.$k."'";
            $comment = \DB::select($sql);
            $data1[$v] = $comment;
        }

        $map2 = [
            'docters' => 'docters(医生表)',
            'docter_organizations' => 'docter_organizations(医生机构关联表)',
            'payments' => 'payments(支付表)',
            'patients' => 'patients(患者档案表)',
            'nurses' => 'nurses(儿保项目表)',
            'vaccines' => 'vaccines(疫苗表)',
            'service_packs' => 'service_packs(服务包表)',
            'time_periods' => 'time_periods(时间段配置表)',
            'teams' => 'teams(团队表)',
            'team_docters' => 'team_docters(团队医生表)',
            'offices' => 'offices(科室表)',
            'user_coupons' => 'user_coupons(用户优惠券表)',
            'user_messages' => 'user_messages(用户消息表)',
            'areas' => 'areas(地区表)',
        ];

        $data2 = array();
        foreach ($map2 as $k => $v){
            $sql = "select COLUMN_NAME name, DATA_TYPE type, COLUMN_COMMENT comment from INFORMATION_SCHEMA.COLUMNS where table_schema = '".$database."' AND table_name = '".$prefix.$k."'";
            $comment = \DB::select($sql);
            $data2[$v] = $comment;
        }

        return view('doc', ['data1' => $data1, 'data2' => $data2]);
    }
}
